@@ -37,6 +37,8 @@ QueryDefinition = TypedDict(
         "sort_by": ExpressionList,
         "expand": List[str],
         "limit": int,
+        "cap": int,
+        "cache": int,
     },
     total=False,
 )
