@@ -3,7 +3,7 @@ from unittest.mock import Mock
 from dotmap import DotMap
 
 from jira_select.types import QueryDefinition
-from jira_select.query import Query
+from jira_select.query import Executor
 
 from .base import JiraSelectTestCase
 
@@ -63,7 +63,7 @@ class TestQuery(JiraSelectTestCase):
             "from": "issues",
         }
 
-        query = Query(self.mock_jira, query)
+        query = Executor(self.mock_jira, query)
 
         actual_results = list(query)
         expected_results = [
@@ -81,7 +81,7 @@ class TestQuery(JiraSelectTestCase):
             "sort_by": ["story_points desc", "key"],
         }
 
-        query = Query(self.mock_jira, query)
+        query = Executor(self.mock_jira, query)
 
         actual_results = list(query)
         expected_results = [
@@ -100,7 +100,7 @@ class TestQuery(JiraSelectTestCase):
             "sort_by": ["len(key)"],
         }
 
-        query = Query(self.mock_jira, query)
+        query = Executor(self.mock_jira, query)
 
         actual_results = list(query)
         expected_results = [
@@ -109,3 +109,80 @@ class TestQuery(JiraSelectTestCase):
         ]
 
         assert expected_results == actual_results
+
+    def test_cap(self):
+        query: QueryDefinition = {
+            "select": ["key"],
+            "from": "issues",
+            "cap": 1,
+        }
+
+        query = Executor(self.mock_jira, query)
+
+        actual_results = list(query)
+        assert len(actual_results) == 1
+
+    def test_simple_wprogress(self):
+        query: QueryDefinition = {
+            "select": ["key"],
+            "from": "issues",
+        }
+
+        query = Executor(self.mock_jira, query, True)
+
+        actual_results = list(query)
+        expected_results = [
+            {"key": "ALPHA-1",},
+            {"key": "ALPHA-3",},
+            {"key": "ALPHA-2",},
+        ]
+
+        assert expected_results == actual_results
+
+    def test_sort_by_wprogress(self):
+        query: QueryDefinition = {
+            "select": ["key"],
+            "from": "issues",
+            "sort_by": ["story_points desc", "key"],
+        }
+
+        query = Executor(self.mock_jira, query, True)
+
+        actual_results = list(query)
+        expected_results = [
+            {"key": "ALPHA-3",},
+            {"key": "ALPHA-1",},
+            {"key": "ALPHA-2",},
+        ]
+
+        assert expected_results == actual_results
+
+    def test_group_by_aggregation_wprogress(self):
+        query: QueryDefinition = {
+            "select": ["issuetype", "len(key)"],
+            "from": "issues",
+            "group_by": ["issuetype"],
+            "sort_by": ["len(key)"],
+        }
+
+        query = Executor(self.mock_jira, query, True)
+
+        actual_results = list(query)
+        expected_results = [
+            {"issuetype": "Bug", "len(key)": 1,},
+            {"issuetype": "Issue", "len(key)": 2,},
+        ]
+
+        assert expected_results == actual_results
+
+    def test_cap_wprogress(self):
+        query: QueryDefinition = {
+            "select": ["key"],
+            "from": "issues",
+            "cap": 1,
+        }
+
+        query = Executor(self.mock_jira, query, True)
+
+        actual_results = list(query)
+        assert len(actual_results) == 1
